@@ -130,9 +130,9 @@ def data_integrety_checks(data, parameter, ds_metadata, attrs, encoding):
         raise ValueError('Data is not indexed correctly.')
 
     # Check for station_id
-    if data_grouping != 'blocks':
+    if (data_grouping != 'blocks') and (sd != 'grid'):
         if 'station_id' not in vars1:
-            raise ValueError('If the grouping is not blocks, then the station_id should be in the data.')
+            raise ValueError('If the grouping is not blocks and/or spatial_distribution is not grid, then the station_id should be in the data.')
 
     # if data_grouping == 'blocks':
     #     if 'extent' not in data_index:
@@ -208,6 +208,14 @@ def package_xarray(data, parameter, attrs, encoding, run_date=None, compression=
             extent_hex = extent.wkb_hex
             data1 = data1.assign_coords({'extent': [extent_hex]})
             data1 = data1.assign({'station_id': (('extent'), [stn_id])})
+    elif grouping == 'none':
+        if 'station_id' not in data1:
+            if sd == 'grid':
+                lat = float(data1['lat'].values[0])
+                lon = float(data1['lon'].values[0])
+                geometry = geojson.Point([lon, lat], True, precision=5)
+                stn_id = assign_station_id(geometry)
+                data1 = data1.assign({'station_id': (('lon', 'lat'), [[stn_id]])})
 
     ## Assign Attributes
     attrs1 = {'station_id': {'cf_role': "timeseries_id"}, 'lat': {'standard_name': "latitude", 'units': "degrees_north"}, 'lon': {'standard_name': "longitude", 'units': "degrees_east"}, 'altitude': {'standard_name': 'surface_altitude', 'long_name': 'height above the geoid to the lower boundary of the atmosphere', 'units': 'm'}, 'geometry': {'long_name': 'The hexadecimal encoding of the Well-Known Binary (WKB) geometry', 'crs_EPSG': 4326}, 'extent': {'long_name': 'The hexadecimal encoding of the Well-Known Binary (WKB) station extent', 'crs_EPSG': 4326}, 'height': {'standard_name': 'height', 'long_name': 'vertical distance above the surface', 'units': 'm', 'positive': 'up'}, 'time': {'standard_name': 'time', 'long_name': 'start_time'}}
@@ -785,7 +793,12 @@ def prepare_new_xr(ts_data, stn_data, mod_date=True):
     """
 
     """
-    stn = stn_data.to_frame().T.set_index('geometry').to_xarray()
+    if isinstance(stn_data, pd.Series):
+        stn = stn_data.to_frame().T.set_index('geometry').to_xarray()
+    elif isinstance(stn_data, pd.DataFrame):
+        stn = stn_data.set_index('geometry').to_xarray()
+    elif isinstance(stn_data, dict):
+        stn = pd.DataFrame([stn_data]).set_index('geometry').to_xarray()
 
     obs2 = ts_data.copy()
 
@@ -857,14 +870,18 @@ def get_station_data_from_xr(data):
     lat_lon = ['lon', 'lat']
 
     stn_vars = [v for v in vars1 if (not v in dims1) and (not v in data_vars) and (not v in lat_lon)]
-    stn_data1 = {k: v['data'][0] for k, v in data[stn_vars].to_dict()['data_vars'].items() if k in stn_fields}
+    if ('geometry' in dims1) or ('extent' in dims1):
+        stn_data1 = {k: v['data'][0] for k, v in data[stn_vars].to_dict()['data_vars'].items() if k in stn_fields}
+        props = {s: {'data': data[s].to_dict()['data'][0], 'attrs': data[s].to_dict()['attrs']} for s in stn_vars if s not in stn_fields}
+    else:
+        stn_data1 = {k: v['data'][0][0] for k, v in data[stn_vars].to_dict()['data_vars'].items() if k in stn_fields}
+        props = {s: {'data': data[s].to_dict()['data'][0][0], 'attrs': data[s].to_dict()['attrs']} for s in stn_vars if s not in stn_fields}
     stn_data1.update({'geometry': geo1})
     if 'altitude' in stn_data1:
         stn_data1['altitude'] = round(stn_data1['altitude'], 3)
     # if not 'virtual_station' in stn_data1:
     #     stn_data1['virtual_station'] = False
 
-    props = {s: {'data': data[s].to_dict()['data'][0], 'attrs': data[s].to_dict()['attrs']} for s in stn_vars if s not in stn_fields}
     if props:
         stn_data1['properties'] = props
 
