@@ -317,7 +317,7 @@ def compare_datasets_from_s3(conn_config, bucket, new_data, add_old=False, last_
     dataset = [new_data[v].attrs for v in vars1 if 'dataset_id' in new_data[v].attrs][0]
     dataset_id = dataset['dataset_id']
     # result_type = dataset['result_type']
-    station_id = str(new_data['station_id'].values[0])
+    station_id = str(new_data.squeeze()['station_id'].values)
 
     key_dict = {'dataset_id': dataset_id, 'station_id': station_id}
 
@@ -418,7 +418,7 @@ def update_results_s3(processing_code, data_dict, run_date_dict, remote, threads
                 print('Data could not be opened')
                 return None
 
-            stn_id = str(new1['station_id'].values[0])
+            stn_id = str(new1.squeeze()['station_id'].values)
             print('station_id: ' + stn_id)
 
             vars1 = list(new1.variables)
